#!/bin/bash

# wine-msstuff-setup.sh -- implement the procedure instructed by Sidenet 
# (http://sidenet.ddo.jp/winetips/)
#
#
# nosanosa <nosanosa at momonga-linux.org>

configdir="${HOME}/.wine"

confirm_fakewindir () {
    fakewindir=$1
    if [ x`expr substr "$fakewindir" 1 1` != x"/" ]; then
#      if [ x"$fakewindir" = x"" ]; then
#	  fakewindir=${HOME}/wine
#	  break;
#      fi
      echo "The path of direcotries should be fullpath and must begin with \"/\"."
      usage
      exit 1
    fi
}

setup_mfc40 () {
    if [ -e ./mfc40.dll ]
	then
	echo ""
	echo "------------ MFC40 Setup ------------ "
	echo ""	
	echo "--- Installing mfc40.dll ..."
	echo ""
	cp -f ./mfc40.dll ${fakewindir}/windows/system
    fi
}

setup_ie6 () {
    if [ -e ./ie6setup.exe ]
	then
	echo ""
	echo "------------ Internet Explorer 6 Setup ------------ "
	echo ""
	echo "Notice! You should install Windows Media Player too."
	echo ""
	echo "Notice! Sometimes setup procedure stops and wine-debugger statrs."
	echo "In that case, you should kill the process of wine-debugger from other terminal. Then procedure may continue."
	echo ""
	echo "And setup may really stop even without starting wine-debugger."
	echo "In that case, stop the setup once by \"Ctrl-C\" and the setup will start again and complete the procedure if you are lucky."
	echo "OK?[Hit Return]"
	read x
	echo "--- Setting up Internet Explorer 6 ..."
	echo ""
	cp ./ie6setup.exe /tmp
#	echo "Log file: ie6setup.log"
	
	while [ ! -e ${fakewindir}/Program\ Files/Internet\ Explorer/IEXPLORE.EXE ]
	  do {
#	      wine /tmp/ie6setup.exe 2>&1 |cat > ./ie6setup.log
	      wine /tmp/ie6setup.exe 2>&1
	      wineserver -w
	      echo "Checking if ie6setup needs to be started again ..."
	  }
	done
	ln -s ${fakewindir}/Program\ Files/Internet\ Explorer/IEXPLORE.EXE ${fakewindir}/windows/IEXPLORE.EXE
	ln -s ${fakewindir}/Program\ Files/Windows\ Media\ Player/mplayer2.exe ${fakewindir}/windows/mplayer2.exe
	rm -f /tmp/ie6setup.exe
	
	echo "--- Simulating reboot ..."
	echo ""
	echo "This may take some time."
	echo "Press OK if some error dialog appears."
	echo "OK?[Hit Return]"
	read x
	echo ""
#	echo "Log file: ie6setup_wineboot.log"
#	wineboot 2>&1 |cat > ./ie6setup_wineboot.log
	wineboot 2>&1
#	echo "Launching Internet Explorer ... This may take some time."
#	echo "Press CANCEL if Internet Connection Wizard appears."
#	echo "Log file: iexplore.log"
#	wine iexplore http://sidenet.ddo.jp/winetips/wcsstart.html 2>&1 |cat > ./iexplore.log
	echo "--- Internet Explorer 6 setup completed."
    fi
}

setup_msi () {
    if [ -e ./InstMsiA.exe ]
	then
	echo ""
	echo "------------ Windows Installer Setup -----------"
	echo ""
	echo "--- Setting up Windows Installer ..."
	echo ""
	cp ./InstMsiA.exe /tmp
#	echo "Log file: instmsia.log"
#	wine /tmp/InstMsiA.exe 2>&1 |cat > ./instmsia.log
	wine /tmp/InstMsiA.exe 2>&1 
	rm -f /tmp/InstMsiA.exe
	echo "--- editting msi dll entry in ~/.wine/config"
	perl -p -i -e "s/.*\"msi\".*/\"msi\"        = \"native\"/g" $configdir/config
    fi
}

setup_mp71 () {
    if [ -e ./mp71.exe ]
	then
	echo ""
	echo "------------ Windows Media Player7 Setup -----------"
	echo ""
	echo "Notice! Sometimes setup procedure stops and wine-debugger statrs."
	echo "In that case, you should kill the process of wine-debugger from other terminal and procedure may continue."
	echo "OK?[Hit Return]"
	read x
	echo "Setting up Windows Media Player7..."
	echo ""
	cp ./mp71.exe /tmp
#	echo "Log file: mp71.log"
#	wine /tmp/mp71.exe 2>&1 |cat > ./mp71.log
	wine /tmp/mp71.exe 2>&1
	rm -f /tmp/mp71.exe
	wineserver -w
	echo "Simulating reboot... This may take some time."
#	echo "Log file: mp71_wineboot.log"
#	wineboot 2>&1 |cat > ./mp71_wineboot.log
	wineboot 2>&1
	echo "Setup of Windows Media Player7 completed!"
    fi
}

setup_dcom98 () {
    if [ -e ./dcom98.exe ] || [ -e ./DCOM98.EXE ]
	then
	echo ""
	echo "------------ DCOM98 Setup -----------"
	echo ""	
	echo "--- Setting up DCOM98 ..."
	echo ""
#	echo "Log file: dcom98.log"
	if [ -e ./dcom98.exe ]
	    then
	    cp ./dcom98.exe /tmp
#	    wine /tmp/dcom98.exe 2>&1 | cat > ./dcom98.log
	    wine /tmp/dcom98.exe
	    rm -f /tmp/dcom98.exe
	else
	    cp ./DCOM98.EXE /tmp
#	    wine /tmp/DCOM98.EXE 2>&1 | cat > ./dcom98.log
	    wine /tmp/DCOM98.EXE 2>&1
	    rm -f /tmp/DCOM98.EXE
	fi
	echo "--- editting ole32 dll setting in ~/.wine/config"
	perl -p -i -e "s/.*\"ole32\".*/\"ole32\"        = \"native\"/g" $configdir/config
	echo "--- DCOM98 setup completed."
	wineserver -w
    else
	echo ""
	echo "You need to put DCOM98.EXE or dcom98.exe in current directory!"
	echo ""
	exit 0
    fi
}

usage () {
    echo "$0: setup MS stuff for Wine"
    echo "You may want to execute wine-get-msstuff.sh  beforehand to download MS stuff"
    echo ""
    echo "Usage: $0 FAKE_WINDOWS_DIR [options]"
    echo ""
    echo "  FAKE_WINDOWS_DIR is the directory which is asigned as Windows C drive." 
    echo "  It must be specified with fullpath"
    echo ""
    echo "  options"
    echo ""
    echo "    --dcom98 : install DCOM98"
    echo "    --ie6    : install Internet Explorer 6 SP1"
    echo "    --msi    : install MS Installer"
    echo "    --mfc40  : install MFC 4.0 DLL"
    echo "    --wmp7   : install Windows Media Player 7.1"
    echo "    --all    : same as \"--dcom98 --ie6 --msi --mfc40 --wmp7 (recommended) \""
    echo ""
    exit
}


if [ ! -e ~/.wine ]; then
    echo "Wine configuration is not found!"
    echo "Setup Wine by wine-setup first"
    exit 1
fi

if [ -z "$*" ]; then
    usage
fi

echo "----------- Setting up of MS stuff for WINE -----------"

confirm_fakewindir $1

unset SETUP_DCOM98
unset SETUP_IE6
unset SETUP_MSI
unset SETUP_MFC40
unset SETUP_MP71
for i in $*
do
  case "$i" in 
      --ie6 )
	  if [ ! -e ./ie6setup.exe ]; then
	      echo "You have to put ie6setup.exe in current directory"
	      exit 1
	  fi
	  SETUP_IE6=y
	  ;;
      --msi )
	  if [ ! -e ./InstMsiA.exe ];then
	      echo "You have to put InstMsiA.exe in current directory"
	      exit 1
	  fi
	  SETUP_MSI=y
	  ;;
      --wmp7 )
	  if [ ! -e ./mp71.exe ]; then
	      echo "You have to put mp71.exe in current directory"
	      exit 1	      
	  fi
	  SETUP_MP71=y
	  ;;
      --mfc40 )
	  if [ ! -e ./mfc40.dll ]; then
	      echo "You have to put mfc40.dll in current directory"
	      exit 1	      
	  fi	  
	  SETUP_MFC40=y
	  ;;
      --dcom98 )
	  if [ ! -e ./dcom98.exe ]; then
	      echo "You have to put dcom98.exe in current directory"
	      exit 1	      
	  fi
	  SETUP_DCOM98=y
	  ;;
      --all )
	  if [ ! -e ./ie6setup.exe ]; then
	      echo "You have to put ie6setup.exe in current directory"
	      exit 1
	  fi
	  SETUP_IE6=y
	  if [ ! -e ./InstMsiA.exe ];then
	      echo "You have to put InstMsiA.exe in current directory"
	      exit 1
	  fi
	  SETUP_MSI=y
	  if [ ! -e ./mp71.exe ]; then
	      echo "You have to put mp71.exe in current directory"
	      exit 1	      
	  fi
	  SETUP_MP71=y
	  if [ ! -e ./mfc40.dll ]; then
	      echo "You have to put mfc40.dll in current directory"
	      exit 1	      
	  fi	  
	  SETUP_MFC40=y
	  if [ ! -e ./dcom98.exe ]; then
	      echo "You have to put dcom98.exe in current directory"
	      exit 1	      
	  fi
	  SETUP_DCOM98=y
	  ;;
      * )
	  ;;
  esac  
done

echo "Stopping wine process ..."
wineserver -k
if [ x"$SETUP_DCOM98" = x ]; then
    if ! grep "^\"ole32\" * = \"native\"" $configdir/config ; then
	echo "DCOM98 has been not installed"
	echo "You have to install DCOM98 before installing other stuffs"
	echo "Please run with --dcom98 option"
	exit 1
    fi
else
    setup_dcom98
fi

if [ x"$SETUP_MFC40" = xy ]; then
    setup_mfc40
fi

if [ x"$SETUP_MSI" = xy ]; then
    setup_msi
fi

if [ x"$SETUP_IE6" = xy ]; then
    setup_ie6
fi

if [ x"$SETUP_MP71" = xy ]; then
    setup_mp71
fi

echo
echo "---All setup completed."
echo ""
echo "If you are lucky, you can run Internet Explorer 6 SP1 by typing \"wine IEXPLORE.EXE\" and run Windows Media Player6.4 by typing \"wine mplayer2.exe \""
echo ""
